pub async fn get_count_in_course_by_status(
conn: &mut PgConnection,
course_id: Uuid,
status: SuspectedCheaterStatus,
) -> ModelResult<i64>Expand description
Counts the suspected cheaters in a given review state for a course.
pub async fn get_count_in_course_by_status(
conn: &mut PgConnection,
course_id: Uuid,
status: SuspectedCheaterStatus,
) -> ModelResult<i64>Counts the suspected cheaters in a given review state for a course.